@@ -61,7 +61,11 @@ define([
             //     // this.dataPath = com_Const.DATA_PATH + "sample_csv/";
             //     this.dataPath = 'https://raw.githubusercontent.com/visualpython/visualpython/main/data/sample_csv/';
             // }
-            this.dataPath = 'https://raw.githubusercontent.com/visualpython/visualpython/main/visualpython/data/sample_csv/';
+            if (vpConfig.extensionType === 'lite') {
+                this.dataPath = '/drive/data/';
+            } else {
+                this.dataPath = 'https://raw.githubusercontent.com/visualpython/visualpython/main/visualpython/data/sample_csv/';
+            }
 
             this.state = {
                 fileExtension: 'csv',
@@ -369,7 +373,7 @@ define([
             // prepend user option
             let hasAllocateTo = $(this.wrapSelector(prefix + '#o0')).length > 0;
             if (hasAllocateTo) {
-                $(this.wrapSelector(prefix + '#o0')).closest('tr').before(
+                $(this.wrapSelector(prefix + '#o0')).closest('tr').after(
                     $('<tr>').append($(`<td><label for="userOption">User Option</label></td>`))
                         .append($('<td><input id="userOption" type="text" class="vp-input vp-state" placeholder="key=value, ..."/></td>'))
                 )
